@@ -5,16 +5,13 @@ import static org.gcube.resources.discovery.icclient.ICFactory.queryFor;
 
 import java.util.Iterator;
 import java.util.List;
-
 import org.gcube.common.resources.gcore.ServiceEndpoint;
 import org.gcube.common.resources.gcore.ServiceEndpoint.AccessPoint;
 import org.gcube.common.scope.api.ScopeProvider;
 import org.gcube.resources.discovery.client.api.DiscoveryClient;
 import org.gcube.resources.discovery.client.queries.api.SimpleQuery;
-
-import com.liferay.portal.kernel.log.Log;
-import com.liferay.portal.kernel.log.LogFactoryUtil;
-
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 /**
  * Retrieves the base url of the social-networking service in the scope provided
  * @author Costantino Perciante at ISTI-CNR 
@@ -24,8 +21,7 @@ public class ServiceEndPointReaderSocial {
 
 	private String basePath = null;
 
-	//private static Logger logger = LoggerFactory.getLogger(ServiceEndPointReaderSocial.class);
-	private static final Log logger = LogFactoryUtil.getLog(ServiceEndPointReaderSocial.class);
+	private static Logger logger = LoggerFactory.getLogger(ServiceEndPointReaderSocial.class);
 	private final static String RUNTIME_RESOURCE_NAME = "SocialNetworking";
 	private final static String CATEGORY = "Portal";
 
